@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 from __future__ import annotations
 
-__version__ = "1.4.0"
+__version__ = "2.0.0"
 
 import sys
 
@@ -296,11 +296,13 @@ class Binary:
             might be something like "macOS 11.xx.
         extractpath: in the case of using a .zip file as url, the extract path should indicate
             a relative path to the binary within the .zip file structure
+        post_install_script: a script to run after the binary has been installed
     """
     platform: str
     url: str
     build_platform: str = ''
     extractpath: str = ''
+    post_install_script: str = ''
 
     def binary_filename(self) -> str:
         """
@@ -457,6 +459,10 @@ class Plugin:
         path = self.resolve_doc_folder() / markdownfile
         return path if path.exists() else None
 
+    def resolve_path(self, relpath: Union[Path, str]) -> Path:
+        root = self.local_manifest_path().parent
+        return _resolve_path(relpath, root)
+
     def resolve_doc_folder(self) -> Path:
         """
         Resolve the doc folder for this plugin
@@ -471,6 +477,18 @@ class Plugin:
             raise OSError(f"No doc folder found (declared as {doc_folder}")
         return doc_folder
 
+    def binarydef_for_platform(self, platform: str = None) -> Optional[Binary]:
+        """
+        Return the Binary for the given platform
+
+        If platform is None, use the current platform
+        """
+        if platform is None:
+            platform = register.platform
+
+        return self.binaries.get(platform)
+
+
 
 @dataclass
 class Opcode:
@@ -948,7 +966,8 @@ def _parse_binarydef(platform: str, binarydef: dict, substitutions: Dict[str, st
     if not build_platform:
         raise ParseError(f"Plugin definition for {platform} should have a build_platform")
     return Binary(platform=platform, url=url, build_platform=build_platform,
-                  extractpath=binarydef.get('extractpath', ''))
+                  extractpath=binarydef.get('extractpath', ''),
+                  post_install_script=binarydef.get('post_install', ''))
 
 
 def _parse_asset(assetdef: dict, defaultsource: str) -> Asset:
@@ -1744,6 +1763,11 @@ class MainIndex:
             _errormsg(f"   manifest was: \n{manifest}")
             return ErrorMsg("Error when dumping manifest to json")
 
+        binarydef = plugin.binarydef_for_platform()
+        if binarydef and binarydef.post_install_script:
+            script = plugin.resolve_path(binarydef.post_install_script)
+            subprocess.call(script.as_posix(), shell=True)
+
         with open(manifest_path.as_posix(), "w") as f:
             f.write(manifest_json)
         _debug(f"Saved manifest for plugin {plugin.name} to {manifest_path}")
